@@ -31,7 +31,6 @@ describe 'keystone::federation::identity_provider' do
       "include apache
        class { 'keystone':
          service_name => 'httpd',
-         enable_ssl   => true,
        }"
     end
 
@@ -103,7 +102,6 @@ describe 'keystone::federation::identity_provider' do
     let :pre_condition do
       "class { 'keystone':
          service_name => '#{platform_params[:keystone_service]}',
-         enable_ssl   => true,
        }"
     end
 
@@ -121,7 +119,7 @@ describe 'keystone::federation::identity_provider' do
       end
 
       let (:platform_params) do
-        if facts[:osfamily] == 'RedHat'
+        if facts[:os]['family'] == 'RedHat'
           keystone_service = 'openstack-keystone'
           python_pysaml2_package_name = 'python3-pysaml2'
         else
